@@ -1,8 +1,8 @@
-package boolean;
 use 5.005003;
+package boolean;
 use strict;
-# use warnings;
-$boolean::VERSION = '0.26';
+
+$boolean::VERSION = '0.29';
 
 my ($true, $false);
 
@@ -19,6 +19,13 @@ use base 'Exporter';
     test   => [qw(isTrue isFalse isBoolean)],
 );
 
+sub import {
+    my @options = grep $_ ne '-truth', @_;
+    $_[0]->truth if @options != @_;
+    @_ = @options;
+    goto &Exporter::import;
+}
+
 my ($true_val, $false_val, $bool_vals);
 
 BEGIN {
@@ -60,6 +67,20 @@ sub isBoolean($) {
     (exists $bool_vals->{overload::StrVal($_[0])}) ? true : false;
 }
 
+sub truth {
+    # enable modifying true and false
+    &Internals::SvREADONLY( \ !!0, 0);
+    &Internals::SvREADONLY( \ !!1, 0);
+    # turn perl internal booleans into blessed booleans:
+    ${ \ !!0 } = $false;
+    ${ \ !!1 } = $true;
+    # make true and false read-only again
+    &Internals::SvREADONLY( \ !!0, 1);
+    &Internals::SvREADONLY( \ !!1, 1);
+}
+
+sub TO_JSON() { ${$_[0]} ? \1 : \0 }
+
 1;
 
 =encoding utf8
@@ -86,6 +107,13 @@ and:
     do &something if isTrue($guess);
     do &something_else if isFalse($guess);
 
+and:
+
+    use boolean -truth;
+
+    die unless ref(42 == 42) eq 'boolean';
+    die unless ("foo" =~ /bar/) eq '0';
+
 =head1 DESCRIPTION
 
 Most programming languages have a native C<Boolean> data type.
@@ -174,7 +202,7 @@ Same as isFalse($boolean).
 
 =back
 
-=head1 EXPORTABLES
+=head1 USE OPTIONS
 
 By default this module exports the C<true>, C<false> and C<boolean> functions.
 
@@ -188,13 +216,27 @@ Exports C<true>, C<false>, C<boolean>, C<isTrue>, C<isFalse>, C<isBoolean>
 
 =back
 
+=head2 -truth
+
+You can specify the C<-truth> option to override truth operators to return
+C<boolean> values.
+
+    use boolean -truth;
+    print ref("hello" eq "world"), "\n";
+
+Prints:
+
+    boolean
+
+C<-truth> can be used with the other import options.
+
 =head1 AUTHOR
 
 Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007, 2008, 2010, 2011. Ingy döt Net.
+Copyright (c) 2007, 2008, 2010, 2011, 2013. Ingy döt Net.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
